pygeodesy.hausdorff.Hausdorff

Package pygeodesy :: Module hausdorff :: Class Hausdorff |
[frames] | no frames]

# Class Hausdorff

      object --+
               |
    named._Named --+
                   |
                  Hausdorff

Known Subclasses:
  - _HausdorffMeterRadians
  - , HausdorffDegrees
  - , HausdorffDistanceTo
  - , HausdorffEquirectangular
  - , HausdorffExact
  - , HausdorffKarney
  - , HausdorffRadians

Hausdorff base class, requires method Hausdorff.distance to be overloaded.

Instance Methods
__init__(self, point1s, seed=None, units='', **name__kwds) New `Hausdorff...` calculator. |
directed(self, point2s, early=True) Compute only the `forward Hausdorff` distance. |
distance(self, point1, point2) Return the distance between `point1` and `point2`, subject to the supplied optional keyword arguments, see property `kwds`. |
point(self, point) Convert a `model` or `target` point for the `.distance` method. |
symmetric(self, point2s, early=True) Compute the combined `forward and reverse Hausdorff` distance. |
Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__repr__`, `__rmatmul__`, `__str__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toRepr`, `toStr`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
| adjust Get the adjust setting (`bool` or `None` if not applicable).
| datum Get the datum of this calculator (Datum or `None` if not applicable).
| kwds Get the supplied, optional keyword arguments (`dict`).
| seed Class `property` with a `.name` attribute.
| units Class `property` with a `.name` attribute.
| wrap Get the wrap setting (`bool` or `None` if not applicable).
Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, point1s, seed=None, units='', **name__kwds) (Constructor) |
New `Hausdorff...` calculator. Arguments: `point1s` - Initial set of points, aka the `model` or `template` (`LatLon`[], `Numpy2LatLon`[], `Tuple2LatLon`[] or `other`[]). `seed` - Random sampling seed (`any`) or `None`, `0` or `False` for no random sampling. `units` - Optional, the distance units (`Unit` or `str`). `name__kwds` - Optional calculator/interpolator `name=NN` (`str`) and keyword arguments for the distance function, retrievable with property `kwds`. Raises: `HausdorffError` - Insufficient number of `point1s` or an invalid `point1`, `seed` or `units`. Overrides: object.__init__

### directed (self, point2s, early=True) |
Compute only the `forward Hausdorff` distance. Arguments: `point2s` - Second set of points, aka the `target` (`LatLon`[], `Numpy2LatLon`[], `Tuple2LatLon`[] or `other`[]). `early` - Enable or disable early breaking (`bool`). Returns: A Hausdorff6Tuple`(hd, i, j, mn, md, units)`. Raises: `HausdorffError` - Insufficient number of `point2s` or an invalid `point2`. Note: See `point2s` note at HausdorffDistanceTo.

### symmetric (self, point2s, early=True) |
Compute the combined `forward and reverse Hausdorff` distance. Arguments: `point2s` - Second set of points, aka the `target` (`LatLon`[], `Numpy2LatLon`[], `Tuple2LatLon`[] or `other`[]). `early` - Enable or disable early breaking (`bool`). Returns: A Hausdorff6Tuple`(hd, i, j, mn, md, units)`. Raises: `HausdorffError` - Insufficient number of `point2s` or an invalid `point2`. Note: See `point2s` note at HausdorffDistanceTo.

Property Details

### adjust Get the adjust setting (`bool` or `None` if not applicable). Get method: adjust(self) - Get the adjust setting (`bool` or `None` if not applicable). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### datum Get the datum of this calculator (Datum or `None` if not applicable). Get method: datum(self) - Get the datum of this calculator (Datum or `None` if not applicable). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### kwds Get the supplied, optional keyword arguments (`dict`). Get method: kwds(self) - Get the supplied, optional keyword arguments (`dict`). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.

### seed Class `property` with a `.name` attribute. Get method: seed(self) - Get the random sampling seed (`any` or `None`). Set method: seed(self, seed) - Set the random sampling seed (`Random(seed)`) or `None`, `0` or `False` for no random sampling.

### units Class `property` with a `.name` attribute. Get method: units(self) - Get the distance units (`Unit` or `str`). Set method: units(self, units) - Set the distance units (`Unit` or `str`).

### wrap Get the wrap setting (`bool` or `None` if not applicable). Get method: wrap(self) - Get the wrap setting (`bool` or `None` if not applicable). Set method: _fset_error(inst, val) - Throws an `AttributeError`, always. Delete Method: _fdel(inst) - Zap the cached/memoized `property` value.